# Crypto API Reference

## CryptoClient

::: pyhood.crypto.client.CryptoClient

## Authentication

::: pyhood.crypto.auth.generate_keypair

::: pyhood.crypto.auth.sign_request

## Models

::: pyhood.crypto.models
